intelmq.bots.parsers.anubisnetworks package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.parsers.anubisnetworks package

## Submodules

## intelmq.bots.parsers.anubisnetworks.parser module

AnubisNetworks Cyberfeed Stream parser

TODO: Refactor with JSON mapping

There is an old format and a new one - distinguishable by the test cases

Migration to ParserBot does not make sense, as there’s only one event per report anyway

class `intelmq.bots.parsers.anubisnetworks.parser.` `AnubisNetworksParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `event_add_fallback`(event, key, value)
  `init`()
  `parse_geo`(event, value, namespace, raw_report, orig_name)
  `process`()

`intelmq.bots.parsers.anubisnetworks.parser.` `BOT`

  alias of `intelmq.bots.parsers.anubisnetworks.parser.AnubisNetworksParserBot`

## Module contents